#!/usr/bin/env python3

# todo: Problems might arise with casing if there are overlaps such as 'Tag' and 'tag'.

from sys import argv, exit
import time, urllib.parse, re
from os import walk
import os.path as path

from article_utils import the_line_after_metadata, parse_metadata
from page_builder import wrap_page

# todo: Reuse
tag_listing_header = """CSS:    /style.css
HTML header:    <meta name="viewport" content="width=device-width, initial-scale=1">

"""
main_listing_header = """CSS:    /style.css
HTML header:    <meta name="viewport" content="width=device-width, initial-scale=1">

"""

if len(argv) <= 1:
    print("No article directory was supplied")
    exit(-1)

if len(argv) <= 2:
    print("No tag listing output directory was supplied")
    exit(-1)

tag_to_tag_page = {}
tag_to_articles = {}
tag_counts = {}
article_to_title = {}

for root, dirs, _ in walk(argv[1]):
    for d in dirs:
        metadata = parse_metadata(path.abspath(root + '/' + d + "/page.mmd"))
        article = "/articles/" + urllib.parse.quote(d) + ".html"
        for tag in metadata.get('Tags', []):
            tag_to_articles[tag] = tag_to_articles.get(tag, []) + [article]
            tag_counts[tag] = tag_counts.get(tag, 0) + 1
            article_to_title[article] = metadata['Title']
    break

for tag in tag_to_articles:
    tag_page = f"/tags/{urllib.parse.quote(tag.lower())}.html"
    tag_to_tag_page[tag] = tag_page

    with open(argv[2] + tag_page, 'w') as f:
        tagged_article_listing = f"\n# Tagged {tag} #\n---\n" + \
            '\n'.join(f"- [{article_to_title[article]}]({article})" \
                for article in tag_to_articles[tag])
        f.write(tag_listing_header + wrap_page(tagged_article_listing))

main_listing = "\n# Tag Listing #\n---\n" + \
    ', '.join(f"[{tag}]({tag_to_tag_page[tag]}) ({tag_counts[tag]})" \
        for tag in sorted(tag_counts.keys(), key=lambda x: tag_counts[x], reverse=True)) + \
    '\n\n'

print(main_listing_header + wrap_page(main_listing))
